@@ -11,7 +11,12 @@ import publication
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-iotanalytics", "1.48.0", __name__[0:-6], "aws-iotanalytics@1.48.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-iotanalytics",
+    "1.50.0",
+    __name__[0:-6],
+    "aws-iotanalytics@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
